]> git.tuebingen.mpg.de Git - paraslash.git/blobdiff - recv.h
paraslash 0.7.3
[paraslash.git] / recv.h
diff --git a/recv.h b/recv.h
index f1e2fc4563735a67f149bdc69d1bbf7f526497d6..391395b241d67abf12eb70996a10ee7950519087 100644 (file)
--- a/recv.h
+++ b/recv.h
@@ -1,8 +1,4 @@
-/*
- * Copyright (C) 2005 Andre Noll <maan@tuebingen.mpg.de>
- *
- * Licensed under the GPL v2. For licencing details see COPYING.
- */
+/* Copyright (C) 2005 Andre Noll <maan@tuebingen.mpg.de>, see file COPYING. */
 
 /** \file recv.h Receiver-related structures and exported symbols of recv_common.c. */
 
@@ -25,11 +21,11 @@ struct receiver_node {
        /**
         * The file descriptor to receive the stream.
         *
* The pre_select function of the receiver adds this file descriptor to
         * the set of file descriptors which are watched for readability or
         * writability, depending on the state of the connection (if any).
         *
* If \a fd is readable, the post_select function of the receiver reads
         * data from this fd into the buffer pool area of \a btrp.
         *
         * \sa \ref receiver.
@@ -38,27 +34,26 @@ struct receiver_node {
 };
 
 /**
- * Describes one supported paraslash receiver.
+ * Describes a possible data source for audio streams.
+ *
+ * A paraslash receiver is a modular piece of software which is capable of
+ * receiving an audio data stream from a data source. Received audio data is
+ * fed to consumers through the buffer tree mechanism.
  *
- * \sa \ref http_recv.c, \ref udp_recv.c.
+ * This structure contains the methods which have to be implemented by each
+ * receiver.
+ *
+ * \sa \ref http_recv.c, \ref udp_recv.c, \ref dccp_recv.c, \ref afh_recv.c,
+ * struct \ref receiver_node, struct \ref filter, struct \ref writer, struct
+ * \ref sched.
  */
 struct receiver {
-       /**
-        * The optional receiver init function.
-        *
-        * Performs any initialization needed before the receiver can be opened.
-        */
-       void (*init)(void);
        /**
         * Open one instance of the receiver.
         *
-        * This should allocate the output buffer of \a rn. and may also
-        * perform any other work necessary for retrieving the stream according
-        * to the configuration stored in the \a conf member of \a rn which is
-        * guaranteed to point to valid configuration data (as previously
-        * obtained from the config parser).
-        *
-        * \sa struct \ref receiver_node.
+        * This should allocate the output buffer of the given receiver node
+        * and prepare it for retrieving the audio stream according to the
+        * configuration stored in rn->lpr.
         */
        int (*open)(struct receiver_node *rn);
        /**
@@ -70,34 +65,14 @@ struct receiver {
         * \sa \ref receiver_node.
         */
        void (*close)(struct receiver_node *rn);
-       /**
-        * Add file descriptors to fd_sets and compute timeout for select(2).
-        *
-        * The pre_select function gets called from the driving application
-        * before entering its select loop. The receiver may use this hook to
-        * add any file descriptors to the sets of file descriptors given by \a
-        * s.
-        *
-        * \sa select(2), \ref time.c, struct \ref sched.
-        */
-       void (*pre_select)(struct sched *s, void *context);
-       /**
-        * Evaluate the result from select().
-        *
-        * This hook gets called after the call to select(). It should check
-        * all file descriptors which were added to any of the fd sets during
-        * the previous call to pre_select. According to the result, it may
-        * then use any non-blocking I/O to establish a connection or to
-        * receive the audio data.
-        *
-        * \sa select(2), struct \ref receiver.
-        */
-       int (*post_select)(struct sched *s, void *context);
-
+       /** Ask the scheduler to monitor receive fds. */
+       void (*pre_monitor)(struct sched *s, void *context);
+       /** Receive data and make it available to consumers. */
+       int (*post_monitor)(struct sched *s, void *context);
        /**
         * Answer a buffer tree query.
         *
-        * This optional function pointer is used for inter node communications
+        * This optional function pointer allows for inter node communication
         * of the buffer tree nodes. See \ref btr_command_handler for details.
         */
        btr_command_handler execute;
@@ -119,7 +94,6 @@ struct receiver {
 /** Iterate over all available receivers. */
 #define FOR_EACH_RECEIVER(i) for (i = 1; lls_cmd(i, recv_cmd_suite); i++)
 
-void recv_init(void);
 int check_receiver_arg(const char *ra, struct lls_parse_result **lprp);
 void print_receiver_helps(bool detailed);
-int generic_recv_pre_select(struct sched *s, struct receiver_node *rn);
+int generic_recv_pre_monitor(struct sched *s, struct receiver_node *rn);
@@ -25,11 +21,11 @@ struct receiver_node {
         * The file descriptor to receive the stream.
         *
-        * The pre_select function of the receiver adds this file descriptor to
+        * The pre_monitor function of the receiver adds this file descriptor to
         * the set of file descriptors which are watched for readability or
         * writability, depending on the state of the connection (if any).
@@ -25,11 +21,11 @@ struct receiver_node {
         * writability, depending on the state of the connection (if any).
         *
-        * If \a fd is readable, the post_select function of the receiver reads
+        * If \a fd is readable, the post_monitor function of the receiver reads
         * data from this fd into the buffer pool area of \a btrp.
         *